@@ -45,13 +45,12 @@ sub migrate {
 
   # Already the right version (make sure migrations table exists)
   my $db = $self->pg->db;
-  return $self if $self->_active($db) == $target;
+  return $self if $self->_active($db, 1) == $target;
 
   # Lock migrations table and check version again
-  local @{$db->dbh}{qw(AutoCommit RaiseError)} = (1, 1);
   my $tx = $db->begin;
   $db->query('lock table mojo_migrations in exclusive mode');
-  return $self if (my $active = $self->_active($db)) == $target;
+  return $self if (my $active = $self->_active($db, 1)) == $target;
 
   # Up
   my $sql;
@@ -74,16 +73,17 @@ sub migrate {
 }
 
 sub _active {
-  my ($self, $db) = @_;
+  my ($self, $db, $create) = @_;
 
-  my $dbh  = $db->dbh;
   my $name = $self->name;
-  local @$dbh{qw(AutoCommit RaiseError)} = (1, 0);
-  my $results
-    = $db->query('select version from mojo_migrations where name = $1', $name);
-  if (my $next = $results->array) { return $next->[0] }
+  my $results;
+  {
+    local $db->dbh->{RaiseError} = 0;
+    my $sql = 'select version from mojo_migrations where name = $1';
+    $results = $db->query($sql, $name);
+  };
+  if ((my $next = $results->array) || !$create) { return $next->[0] || 0 }
 
-  local @$dbh{qw(AutoCommit RaiseError)} = (1, 1);
   $db->query(
     'create table if not exists mojo_migrations (
        name    text unique not null,
